@@ -156,6 +156,10 @@ impl Initial {
         Some(&self.data_path)
     }
     #[inline]
+    pub fn planned_data_path(&self) -> &str {
+        &self.data_path
+    }
+    #[inline]
     pub fn timeout(&self) -> Duration {
         self.timeout
             .default
