@@ -508,9 +508,13 @@ async fn extend_string_value(val: String, op: &crate::op::Op, base: &Path) -> ER
                     .next()
                     .ok_or_else(|| Error::invalid_params("xvalue pipe: command not specified"))?;
                 let cd_cmd = format!("cd \"{}\" && {}", base.to_string_lossy(), cmd);
-                let res =
-                    bmart::process::command("sh", &["-c", &cd_cmd], op.timeout()?, None, None)
-                        .await?;
+                let res = bmart::process::command(
+                    "sh",
+                    &["-c", &cd_cmd],
+                    op.timeout()?,
+                    bmart::process::Options::default(),
+                )
+                .await?;
                 if res.ok() {
                     res.out.join("\n")
                 } else {
